ModulatorFrame

Enum ModulatorFrame 

pub enum ModulatorFrame {
    Preamble {
        tx_delay: u8,
    },
    Lsf(LsfFrame),
    Stream(StreamFrame),
    Packet(PacketFrame),
    EndOfTransmission,
}
Frames for transmission, emitted by the TNC and received by the Modulator.

The TNC is responsible for all timing decisions, making sure these frames are emitted in the correct order, breaks between transmissions, PTT and CSMA. If the modulator is given a ModulatorFrame value, its job is to transmit it immediately by modulating it into the output buffer, or otherwise directly after any previously-supplied frames.

The modulator controls the rate at which frames are drawn out of the TNC. Therefore if the send rate is too high (or there is too much channel activity) then the effect of this backpressure is that the TNC’s internal queues will overflow and it will either discard earlier frames in the current stream, or some packets awaiting transmission.

Variants



Preamble

Fields

tx_delay: u8

TNC’s configured TxDelay setting, increments of 10ms.

TNC fires PTT and it’s up to modulator to apply the setting, taking advantage of whatever buffering already exists in the sound card to reduce the artificial delay.



Lsf(LsfFrame)



Stream(StreamFrame)



Packet(PacketFrame)



EndOfTransmission